#
# spec file for package pam_kwallet
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           pam_kwallet
Version:        5.12.5
Release:        lp150.3.1
Summary:        A PAM Module for KWallet signing
License:        LGPL-2.1 and GPL-2.0+ and GPL-3.0
Group:          System/GUI/KDE
Url:            http://www.kde.org/
Source:         http://download.kde.org/stable/plasma/%{version}/kwallet-pam-%{version}.tar.xz
Source1:        baselibs.conf
# PATCH-FIX-UPSTREAM
Patch1:         0001-Move-salt-creation-to-an-unprivileged-process.patch
# PATCH-FIX-UPSTREAM
Patch2:         0002-Move-socket-creation-to-unprivileged-codepath.patch
# PATCH-FIX-UPSTREAM
Patch3:         0001-Avoid-giving-an-stderr-to-kwallet.patch
BuildRequires:  extra-cmake-modules >= 1.2.0
BuildRequires:  kf5-filesystem
BuildRequires:  libgcrypt-devel >= 1.5.0
BuildRequires:  pam-devel
BuildRequires:  socat
BuildRequires:  xz
Requires:       %{name}-common = %{version}
%if 0%{?suse_version} >= 1330
Requires(post): coreutils pam pam-config
Requires(postun): coreutils pam pam-config
%endif

%description
This PAM module allows you to automatically open your kwallet
when signing into your account.

%package common
Summary:        Support files for the KWallet PAM module
Group:          System/GUI/KDE
Requires:       kwalletd5
Requires:       socat

%description common
This package contains support files used by the KWallet PAM
module.

%prep
%setup -q -n kwallet-pam-%{version}
%autopatch -p1

%build
  %cmake_kf5 -d build -- -DLIBEXEC_INSTALL_DIR=%{_kf5_libexecdir} -DCMAKE_INSTALL_PREFIX=/
  %make_jobs

%install
  %kf5_makeinstall -C build

%if 0%{?suse_version} >= 1330
# Due to boo#728586 it is necessary to duplicate this in the 32bit variant.
# So you need to edit baselibs.conf if you change this.
%post
  %{_sbindir}/pam-config -a --kwallet5 || :

%postun
  if [ "$1" = "0" ]; then
    %{_sbindir}/pam-config -d --kwallet5 || :
  fi
%endif

%files
%defattr(-,root,root)
%doc COPYING*
/%{_lib}/security/pam_kwallet5.so

%files common
%defattr(-,root,root)
%doc COPYING*
%config %{_kf5_configdir}/autostart/pam_kwallet_init.desktop
%{_kf5_libexecdir}/pam_kwallet_init

%changelog
* Sat May  5 2018 fabian@ritter-vogt.de
- Add patch to address regression introduced by previous fixes:
  * 0001-Avoid-giving-an-stderr-to-kwallet.patch
* Thu May  3 2018 fabian@ritter-vogt.de
- Add patches to fix boo#1090863/CVE-2018-10380:
  * 0001-Move-salt-creation-to-an-unprivileged-process.patch
  * 0002-Move-socket-creation-to-unprivileged-codepath.patch
* Wed May  2 2018 fabian@ritter-vogt.de
- Update to 5.12.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.5.php
- Changes since 5.12.4:
  * None
* Tue Mar 27 2018 fabian@ritter-vogt.de
- Update to 5.12.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.4.php
- Changes since 5.12.3:
  * None
* Tue Mar  6 2018 fabian@ritter-vogt.de
- Update to 5.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.3.php
- Changes since 5.12.2:
  * None
* Wed Feb 21 2018 lbeltrame@kde.org
- Update to 5.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.2.php
- Changes since 5.12.1:
  * None
* Tue Feb 13 2018 fabian@ritter-vogt.de
- Update to 5.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.1.php
- Changes since 5.12.0:
  * None
* Fri Feb  2 2018 fabian@ritter-vogt.de
- Update to 5.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.0.php
- Changes since 5.11.95:
  * None
* Mon Jan 15 2018 fabian@ritter-vogt.de
- Update to 5.11.95
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.95.php
- Changes since 5.11.5:
  * Remove obsolete reviewboardrc file
* Tue Jan  2 2018 fabian@ritter-vogt.de
- Update to 5.11.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.5.php
- Changes since 5.11.4:
  * None
* Thu Nov 30 2017 fabian@ritter-vogt.de
- Update to 5.11.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.4.php
- Changes since 5.11.3:
  * None
* Tue Nov  7 2017 fabian@ritter-vogt.de
- Update to 5.11.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.3.php
- Changes since 5.11.2:
  * None
* Tue Oct 24 2017 fabian@ritter-vogt.de
- Update to 5.11.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.2.php
- Changes since 5.11.1:
  * None
* Tue Oct 17 2017 fabian@ritter-vogt.de
- Update to 5.11.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.1.php
- Changes since 5.11.0:
  * None
* Thu Oct  5 2017 fabian@ritter-vogt.de
- Update to 5.11.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.0.php
- Changes since 5.10.95:
  * None
* Thu Sep 14 2017 fabian@ritter-vogt.de
- Update to 5.10.95
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.95.php
- Changes since 5.10.5:
  * Avoid dropping privileges by initializing gcrypt secmem
  * Check for a graphical session
  * Several cleanups
  * Handle differences in PAM headers
- Remove patches, now upstream:
  * 0001-Several-cleanups.patch
  * 0002-Avoid-dropping-privileges-by-initializing-gcrypt-sec.patch
  * 0003-Check-for-a-graphical-session.patch
* Fri Aug 25 2017 jengelh@inai.de
- Besides %%postun, %%post also uses pam-config and should specify
  this as requires.
* Tue Aug 22 2017 fabian@ritter-vogt.de
- Update to 5.10.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.5.php
- Changes since 5.10.4:
  * None
- Enable pam-config integration on TW
* Wed Aug  9 2017 fabian@ritter-vogt.de
- Add various patches (pending upstream review) to fix several
  issues:
  * 0001-Several-cleanups.patch
  * 0002-Avoid-dropping-privileges-by-initializing-gcrypt-sec.patch
  * 0003-Check-for-a-graphical-session.patch
* Wed Aug  2 2017 fabian@ritter-vogt.de
- Split into pam_kwallet and pam_kwallet common to allow -32bit pkg
  necessary for pam-config integration
- Add baselibs.conf for -32bit pkg
- Register with pam-config automatically (boo#1029942)
- Only use pam-config on TW, where it will be available soon
- Disable pam-config for now, kwallet-pam needs some upstream
  discussions first before it's viable to use...
* Tue Jul 18 2017 fabian@ritter-vogt.de
- Update to 5.10.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.4.php
- Changes since 5.10.3:
  * None
* Tue Jun 27 2017 fabian@ritter-vogt.de
- Update to 5.10.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.3.php
- Changes since 5.10.2:
  * None
* Tue Jun 13 2017 fabian@ritter-vogt.de
- Update to 5.10.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.2.php
- Changes since 5.10.1:
  * None
* Tue Jun  6 2017 fabian@ritter-vogt.de
- Update to 5.10.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.1.php
- Changes since 5.10.0:
  * None
* Fri May 26 2017 fabian@ritter-vogt.de
- Update to 5.10.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.0.php
- Changes since 5.9.95:
  * None
* Thu May 11 2017 fabian@ritter-vogt.de
- Update to 5.9.95
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.95.php
- Changes since 5.9.5:
  * None
* Tue Apr 25 2017 lbeltrame@kde.org
- Update to 5.9.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.5.php
- Changes since 5.9.4:
  * None
* Tue Mar 21 2017 fabian@ritter-vogt.de
- Update to 5.9.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.4.php
- Changes since 5.9.3:
  * None
* Tue Feb 28 2017 fabian@ritter-vogt.de
- Update to 5.9.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.3.php
- Changes since 5.9.2:
  * fix off by one in the socket filename
* Tue Feb 14 2017 fabian@ritter-vogt.de
- Update to 5.9.2
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.2.php
- Changes since 5.9.1:
  * None
* Tue Feb  7 2017 fabian@ritter-vogt.de
- Update to 5.9.1
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.1.php
- Changes since 5.9.0:
  * None
* Thu Jan 26 2017 fabian@ritter-vogt.de
- Update to 5.9.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.0.php
- Changes since 5.8.95:
  * None
* Thu Jan 12 2017 fabian@ritter-vogt.de
- Update to 5.8.95 (Plasma 5.9 Beta)
  * New feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.95.php
- Changes:
  * None
* Wed Jul 13 2016 hrvoje.senjan@gmail.com
- Update to 5.7.1
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.1.php
* Tue May 17 2016 toddrme2178@gmail.com
- Remove unneeded call to ldconfig
* Mon May 16 2016 toddrme2178@gmail.com
- Update to 5.6.4
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.4.php
- Update to 5.6.3
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.3.php
- Fix dependencies.
* Fri Apr  8 2016 toddrme2178@gmail.com
- Initial version
